=======
History
=======

0.2.5 (2019-02-05)
------------------

* fix requirements file format check

0.2.4 (2019-01-29)
------------------

* add --comment to allow mentioning comments with --add

0.2.3 (2019-01-26)
------------------

* add --req-pattern to allow specifying search pattern for requirements files
* raise Error when no requirements files are found

0.2.2 (2019-01-23)
------------------

* Fix empty dependencies display

0.2.1 (2019-01-23)
------------------

* Small fixes

0.2.0 (2019-01-22)
------------------

* Add -a/--add to enable adding packages to requirement files.
* Added -d/--docs to launch docs URL in browser
* Allow version specific querying

0.1.2 (2019-01-20)
------------------

* Display more package info
* added --more/-m for even more info

0.1.1 (2019-01-02)
------------------

* First release on PyPI.
